@@ -15,17 +15,17 @@ build_time_vars = {'ABIFLAGS': '',
  'BLDSHARED': 'cc -pthread -shared -fPIC',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'aarch64-unknown-openbsd7.0',
+ 'BUILD_GNU_TYPE': 'arm-unknown-openbsd7.1',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG -O2 '
-           '-pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g',
+           '-pipe   -fPIC -O2 -pipe -O2 -pipe',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -pipe -g',
+ 'CONFIGURE_CFLAGS': '-O2 -pipe',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -34,21 +34,19 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-loadable-sqlite-extensions' "
-                "'--enable-shared' "
-                "'--srcdir=/usr/obj/ports/Python-3.8.12/Python-3.8.12' "
-                "'--with-fpectl' '--with-threads' '--enable-ipv6' "
-                "'--with-system-expat' '--with-system-ffi' "
-                "'--prefix=/usr/local' '--sysconfdir=/etc' "
-                "'--mandir=/usr/local/man' '--infodir=/usr/local/info' "
-                "'--localstatedir=/var' '--disable-silent-rules' "
-                "'--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe -g' "
-                "'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
+ 'CONFIG_ARGS': "'--enable-shared' '--with-fpectl' '--with-threads' "
+                "'--enable-ipv6' '--with-system-expat' '--with-system-ffi' "
+                "'--enable-loadable-sqlite-extensions' '--prefix=/usr/local' "
+                "'--sysconfdir=/etc' '--mandir=/usr/local/man' "
+                "'--infodir=/usr/local/info' '--localstatedir=/var' "
+                "'--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' "
+                "'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' "
+                "'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/obj/ports/Python-3.8.12/Python-3.8.12/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.8.12/Python-3.8.12/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.8.13/Python-3.8.13/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.8.13/Python-3.8.13/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
@@ -76,7 +74,7 @@ build_time_vars = {'ABIFLAGS': '',
  'DTRACE_OBJS': '',
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
- 'ENSUREPIP': 'no',
+ 'ENSUREPIP': 'upgrade',
  'EXE': '',
  'EXEMODE': 755,
  'EXTRATESTOPTS': '',
@@ -209,7 +207,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -261,7 +259,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -512,16 +510,16 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'aarch64-unknown-openbsd7.0',
+ 'HOST_GNU_TYPE': 'arm-unknown-openbsd7.1',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.8 /usr/local/include/python3.8',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.8',
- 'INSTALL': '/usr/obj/ports/Python-3.8.12/bin/install -c',
- 'INSTALL_DATA': '/usr/obj/ports/Python-3.8.12/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.8.12/bin/install -c  -m 755',
- 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.8.12/bin/install -c -m 755',
- 'INSTALL_SHARED': '/usr/obj/ports/Python-3.8.12/bin/install -c -m 755',
+ 'INSTALL': '/usr/obj/ports/Python-3.8.13/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-3.8.13/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.8.13/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.8.13/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-3.8.13/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.8.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -592,7 +590,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DNDEBUG -O2 -pipe -g  -fPIC',
+ 'OPT': '-DNDEBUG -O2 -pipe   -fPIC',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -623,8 +621,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                             '-Wunreachable-code -DNDEBUG -O2 -pipe -g  -fPIC '
-                             '-O2 -pipe -g -O2 -pipe -g -std=c99 -Wextra '
+                             '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC '
+                             '-O2 -pipe -O2 -pipe -std=c99 -Wextra '
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
@@ -632,7 +630,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I/usr/local/include -I./Include/internal -I. '
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG '
-              '-O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g',
+              '-O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
@@ -640,23 +638,23 @@ build_time_vars = {'ABIFLAGS': '',
                      '-I/usr/local/include -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
-                   '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe -g '
-                   '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -std=c99 '
+                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -I/usr/local/include '
                    '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L/usr/obj/ports/Python-3.8.12/Python-3.8.12 '
+ 'PY_CORE_LDFLAGS': '-L/usr/obj/ports/Python-3.8.13/Python-3.8.13 '
                     '-L/usr/local/lib/',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-L/usr/obj/ports/Python-3.8.12/Python-3.8.12 '
+ 'PY_LDFLAGS_NODIST': '-L/usr/obj/ports/Python-3.8.13/Python-3.8.13 '
                       '-L/usr/local/lib/',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
-                        '-DNDEBUG -O2 -pipe -g  -fPIC -O2 -pipe -g -O2 -pipe '
-                        '-g -std=c99 -Wextra -Wno-unused-result '
+                        '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe '
+                        '-std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
@@ -670,7 +668,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.8.12/Python-3.8.12',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.8.13/Python-3.8.13',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '@SGI_ABI@',
@@ -684,18 +682,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-38',
@@ -712,10 +710,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.8.12/Python-3.8.12 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.8.13/Python-3.8.13 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.8.12/Python-3.8.12 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.8.13/Python-3.8.13 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -737,8 +735,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/ports/Python-3.8.12/Python-3.8.12',
- 'abs_srcdir': '/usr/obj/ports/Python-3.8.12/Python-3.8.12',
+ 'abs_builddir': '/usr/obj/ports/Python-3.8.13/Python-3.8.13',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.8.13/Python-3.8.13',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
